@@ -64,7 +64,7 @@ test_that("Resampling CIFTI and GIFTI files is working", {
         write_dir = tdir
       )
       cii2 <- readcii(
-        cii2_fnames["cifti"],
+        cii2_fnames["cifti"], brainstructures=c("left", "right"),
         surfL_fname=cii2_fnames["surfL"], surfR_fname=cii2_fnames["surfR"]
       )
 
@@ -72,7 +72,7 @@ test_that("Resampling CIFTI and GIFTI files is working", {
       cii3 <- readcii(resample_cifti_from_template(
         original=cii_fname, template=cii2_fnames["cifti"],
         target=file.path(tdir, paste0("v2_", basename(cii_fname)))
-      ))
+      ), brainstructures=c("left", "right"))
 
       try(testthat::expect_equal(cii2$data, cii3$data))
     }
@@ -88,5 +88,5 @@ test_that("Resampling CIFTI and GIFTI files is working", {
   z <- combine_xifti(x,y)
   q2 <- write_cifti(z, paste0(tempfile(), ".dtseries.nii"))
   q3 <- resample_cifti_from_template(q, q2, paste0(tempfile(), ".dtseries.nii"))
-  z <- read_cifti(q3)
+  z <- read_cifti(q3, brainstructures=c("left", "right"))
 })
